@@ -30,9 +30,10 @@ import com.facebook.react.bridge.Promise;
 import com.facebook.react.bridge.ReactApplicationContext;
 import com.facebook.react.bridge.ReactContextBaseJavaModule;
 import com.facebook.react.bridge.ReactMethod;
+import com.facebook.react.bridge.ReadableMap;
 
 public class TrimmerManager extends ReactContextBaseJavaModule {
-  public static final String REACT_PACKAGE = "RNTrimmerManager";
+  static final String REACT_PACKAGE = "RNTrimmerManager";
 
   private final ReactApplicationContext reactContext;
 
@@ -57,4 +58,22 @@ public class TrimmerManager extends ReactContextBaseJavaModule {
     Log.d(REACT_PACKAGE, "getVideoInfo: " + path);
     Trimmer.getVideoInfo(path, promise, reactContext);
   }
+
+  @ReactMethod
+  public void trim(ReadableMap options, Promise promise) {
+    Log.d(REACT_PACKAGE, options.toString());
+    Trimmer.trim(options, promise);
+  }
+  @ReactMethod
+  public void compress(ReadableMap options, Promise promise) {
+    Log.d(REACT_PACKAGE, "compress: not supported");
+    promise.reject("not supported on android", "");
+  }
+
+  @ReactMethod
+  public void getPreviewImageAtPosition(ReadableMap options, Promise promise) {
+    String source = options.getString("source");
+    double sec = options.getDouble("second");
+    Trimmer.getPreviewAtPosition(source, sec, promise);
+  }
 }
