@@ -35,6 +35,7 @@ import com.facebook.react.uimanager.SimpleViewManager;
 import com.facebook.react.uimanager.ThemedReactContext;
 import com.shahenlibrary.Events.EventsEnum;
 import com.shahenlibrary.Events.Events;
+import com.yqritc.scalablevideoview.ScalableType;
 
 import java.util.Map;
 
@@ -50,6 +51,7 @@ public class VideoPlayerViewManager extends SimpleViewManager<VideoPlayerView> {
   private final String SET_PROGRESS_DELAY = "progressEventDelay";
   private final String SET_VIDEO_END_TIME = "endTime";
   private final String SET_VIDEO_START_TIME = "startTime";
+  private final String SET_VIDEO_RESIZE_MODE = "resizeMode";
 
   private final int COMMAND_GET_INFO = 1;
   private final int COMMAND_TRIM_MEDIA = 2;
@@ -102,6 +104,17 @@ public class VideoPlayerViewManager extends SimpleViewManager<VideoPlayerView> {
     );
   }
 
+  @Nullable
+  @Override
+  public Map getExportedViewConstants() {
+    return MapBuilder.of(
+            "ScaleNone", Integer.toString(ScalableType.LEFT_TOP.ordinal()),
+            "ScaleToFill", Integer.toString(ScalableType.FIT_XY.ordinal()),
+            "ScaleAspectFit", Integer.toString(ScalableType.FIT_CENTER.ordinal()),
+            "ScaleAspectFill", Integer.toString(ScalableType.CENTER_CROP.ordinal())
+    );
+  }
+
   @Override
   public void receiveCommand(VideoPlayerView root, int commandId, @Nullable ReadableArray args) {
     assert args != null;
@@ -176,4 +189,9 @@ public class VideoPlayerViewManager extends SimpleViewManager<VideoPlayerView> {
     Log.d(VideoPlayerViewManager.REACT_PACKAGE, "setVideoStartTime: " + String.valueOf(startTime));
     player.setVideoStartAt(mStart);
   }
+
+  @ReactProp(name = SET_VIDEO_RESIZE_MODE)
+  public void setResizeMode(final VideoPlayerView player, String resizeModeOrdinalString) {
+    player.setResizeMode(ScalableType.values()[Integer.parseInt(resizeModeOrdinalString)]);
+  }
 }
