@@ -1,6 +1,6 @@
 #ifndef RNVideoProcessing_Bridging_Header_h
 #define RNVideoProcessing_Bridging_Header_h
 
-#import "RCTBridgeModule.h"
+#import "React/RCTBridgeModule.h"
 
 #endif /* RNVideoProcessing_Bridging_Header_h */
