@@ -15,6 +15,14 @@ import { getActualSource } from '../utils';
 const ProcessingUI = UIManager.RNVideoProcessing;
 
 export class VideoPlayer extends Component {
+  static Constants = {
+    resizeMode: {
+      CONTAIN: ProcessingUI.Constants.ScaleAspectFit,
+      COVER: ProcessingUI.Constants.ScaleAspectFill,
+      STRETCH: ProcessingUI.Constants.ScaleToFill,
+      NONE: ProcessingUI.Constants.ScaleNone
+    }
+  };
   static propTypes = {
     ...View.propTypes,
     play: PropTypes.bool,
@@ -25,10 +33,11 @@ export class VideoPlayer extends Component {
     endTime: PropTypes.number,
     startTime: PropTypes.number,
     progressEventDelay: PropTypes.number,
-    source: PropTypes.string.isRequired
+    source: PropTypes.string.isRequired,
+    resizeMode: PropTypes.string
   };
   static defaultProps = {
-    onChange: noop
+    onChange: noop,
   };
 
   constructor(props) {
@@ -124,9 +133,21 @@ export class VideoPlayer extends Component {
       replay,
       volume,
       style,
+      resizeMode,
       ...props
     } = this.props;
     const mSource = getActualSource(source);
+
+    if (__DEV__) {
+      const isCompatible = Object
+        .values(VideoPlayer.Constants.resizeMode)
+        .includes(resizeMode);
+
+      if (!isCompatible) {
+        console.warn('Wrong resizeMode property, please use VideoPlayer.Constants.resizeMode constants');
+      }
+    }
+
     return (
       <RNVideoPlayer
         style={style}
@@ -140,6 +161,7 @@ export class VideoPlayer extends Component {
         endTime={endTime}
         startTime={startTime}
         replay={replay}
+        resizeMode={resizeMode}
         volume={volume}
         {...props}
       />
