@@ -3,7 +3,7 @@ export function calculateCornerResult(duration, value, width, fromRight) {
   // x -> value
   // x = duration * value / width
   const val = Math.abs(value);
-  const result = (duration * val / width) >> 0;
+  const result = duration * val / width;
   return fromRight
     ? duration - result
     : result;
